import { ClientOptions, GetCustomerPurchasesCallback, GetCustomersBulkInfoCallback, GetCustomersBulkInfoParams } from "../../types";
import { BaseClient } from "../../common/BaseClient.abstract";
import { ICustomersClient } from "../interfaces/CustomersClient.interfaces";
/**
 * class CustomersClient
 * constructor requires options as
 * {
 *  protocol: 'http',
 *  hostname: 'domain.com',
 *  port: 80,
 *  pathnamePrefix?: '/v2/customers',
 *  clientId?: 'my-client-id',
 *  secret?: 'secret key if exists',
 *  agent?: string
 * }
 */
export declare class CustomersClient extends BaseClient implements ICustomersClient {
    /**
     * constructor
     *
     * @param options ClientOptions
     */
    constructor(options: ClientOptions);
    /**
     * Get customer purchases
     *
     * @param applicationUsername - string application-username
     * @param cb - callback method for getting the data.
     * @returns - void
     */
    getCustomerPurchases(applicationUsername: string, cb: GetCustomerPurchasesCallback): void;
    /**
     * Get bulk information about your customers.
     *
     * @param params - GetCustomersBulkInfoParams => limit, skip, applicationUsername
     * @param cb - callback method for getting the data.
     */
    getCustomersBulkInfo(params: GetCustomersBulkInfoParams, cb: GetCustomersBulkInfoCallback): void;
}
